pub struct EncryptionKey {
pub epoch: u64,
pub algorithm: String,
/* private fields */
}Expand description
An encryption key for channel communication.
Fields
epoch: u64Key epoch (incremented on rotation)
algorithm: StringAlgorithm name
Implementations
Sourceimpl EncryptionKey
impl EncryptionKey
Sourcepub fn generate_for(scheme: &EncryptionScheme) -> Self
pub fn generate_for(scheme: &EncryptionScheme) -> Self
Generate a new random encryption key for a specific scheme.
Sourcepub fn from_bytes(bytes: [u8; 32], epoch: u64) -> Self
pub fn from_bytes(bytes: [u8; 32], epoch: u64) -> Self
Create from raw bytes.
Sourcepub fn from_bytes_with_algorithm(
bytes: [u8; 32],
epoch: u64,
algorithm: &str,
) -> Self
pub fn from_bytes_with_algorithm( bytes: [u8; 32], epoch: u64, algorithm: &str, ) -> Self
Create from raw bytes with a specific algorithm tag.
Sourcepub fn fingerprint(&self) -> String
pub fn fingerprint(&self) -> String
Get hex-encoded fingerprint (first 8 bytes of key hash).