pub enum TimeoutAction {
DeliverAnyway,
Discard,
ReturnToSender,
Archive,
}Expand description
What to do when a temporal message times out.
Variants
DeliverAnyway
Deliver the message even though the ideal time has passed.
Discard
Discard the message silently.
ReturnToSender
Return the message to the sender.
Archive
Archive the message for later inspection.