AgenticComm — agent-to-agent and agent-to-human communication engine.
Provides structured messaging, channels, pub/sub, message routing, and
communication history stored in .acomm files.
Re-exports
pub use affect::*;pub use bridges::*;pub use channel::*;pub use crypto::*;pub use encryption::*;pub use format::*;pub use query::*;pub use semantic::*;pub use temporal::*;pub use types::*;pub use workspace::*;
Modules
- affect
- AffectProcessor — emotional contagion model for agent communication.
- bridges
- Sister integration bridge traits for AgenticComm.
- cache
- channel
- ChannelManager — manages channel lifecycle independently.
- contracts
- Contracts bridge — implements agentic-sdk v0.2.0 traits for Comm.
- crypto
- Cryptographic operations for AgenticComm.
- encryption
- Encryption operations for AgenticComm.
- format
- Binary .acomm file format with integrity checking.
- metrics
- query
- CommQueryEngine — indexed query engine for fast message and channel lookups.
- semantic
- SemanticProcessor — graph operations for cognitive fragments.
- temporal
- TemporalScheduler — advanced temporal message scheduling.
- types
- Rich types for the agentic-comm specification.
- workspace
- CommWorkspace — multi-store comparison and cross-referencing.
Structs
- Acomm
Header - File header for .acomm files.
- Channel
- A communication channel.
- Channel
Config - Configuration for a channel.
- Comm
File Lock - Advisory file lock for concurrent access to
.acommfiles. - Comm
Store - The main communication store holding channels, messages, and subscriptions.
- Comm
Store Stats - Summary statistics for a CommStore.
- Dead
Letter - A message that could not be delivered and was placed in the dead letter queue.
- KeyEntry
- A key entry for channel encryption metadata.
- Message
- A single message in the communication system.
- Message
Engine - Unified message processing engine that wraps
CommStoreand provides a higher-level pipeline for sending and querying messages. - Message
Filter - Filter for querying message history.
- Rate
Tracker - Per-sender rate tracking state.
- Subscription
- A pub/sub subscription.
Enums
- Channel
State - Operational state of a channel.
- Channel
Type - The type of a communication channel.
- Comm
Error - All errors produced by the communication engine.
- Dead
Letter Reason - Reason a message was dead-lettered.
- Delivery
Mode - Message delivery semantics.
- Message
Priority - Priority level for a message.
- Message
Status - Lifecycle status of a message.
- Message
Type - The type of a message.
- Retention
Policy - How long messages are retained in a channel.
Constants
- ACOMM_
MAGIC - Magic bytes for the .acomm file format.
- ACOMM_
VERSION - File format version.
- MAX_
CONTENT_ SIZE - Maximum message content size: 1 MB.
Type Aliases
- Comm
Result - Convenience result type.