pub struct ChannelManager { /* private fields */ }Expand description
Manages channel lifecycle, membership, and state transitions.
Implementations
Sourceimpl ChannelManager
impl ChannelManager
Sourcepub fn create(
&mut self,
name: &str,
channel_type: ChannelType,
config: Option<ChannelConfig>,
) -> CommResult<&Channel>
pub fn create( &mut self, name: &str, channel_type: ChannelType, config: Option<ChannelConfig>, ) -> CommResult<&Channel>
Create a new channel and return a reference to it.
Sourcepub fn get_mut(&mut self, id: u64) -> Option<&mut Channel>
pub fn get_mut(&mut self, id: u64) -> Option<&mut Channel>
Get a mutable reference to a channel by id.
Sourcepub fn join(&mut self, channel_id: u64, agent_id: &str) -> CommResult<()>
pub fn join(&mut self, channel_id: u64, agent_id: &str) -> CommResult<()>
Add a participant to a channel.
Sourcepub fn leave(&mut self, channel_id: u64, agent_id: &str) -> CommResult<()>
pub fn leave(&mut self, channel_id: u64, agent_id: &str) -> CommResult<()>
Remove a participant from a channel.
Sourcepub fn close(&mut self, channel_id: u64) -> CommResult<()>
pub fn close(&mut self, channel_id: u64) -> CommResult<()>
Close a channel (sets state to ChannelState::Closed).
Sourcepub fn set_state(
&mut self,
channel_id: u64,
state: ChannelState,
) -> CommResult<()>
pub fn set_state( &mut self, channel_id: u64, state: ChannelState, ) -> CommResult<()>
Transition a channel to a new state.
Sourcepub fn set_config(
&mut self,
channel_id: u64,
config: ChannelConfig,
) -> CommResult<()>
pub fn set_config( &mut self, channel_id: u64, config: ChannelConfig, ) -> CommResult<()>
Update the configuration of a channel.
Sourcepub fn channels(&self) -> &HashMap<u64, Channel>
pub fn channels(&self) -> &HashMap<u64, Channel>
Immutable access to the underlying channel map.
Sourcepub fn channels_mut(&mut self) -> &mut HashMap<u64, Channel>
pub fn channels_mut(&mut self) -> &mut HashMap<u64, Channel>
Mutable access to the underlying channel map.